<?php
/**
 * ownCloud Admin_Audit
 *
 * @author Sujith Haridasan <sharidasan@owncloud.com>
 * @copyright (C) 2017 ownCloud, Inc.
 *
 * This code is covered by the ownCloud Commercial License.
 *
 * You should have received a copy of the ownCloud Commercial License
 * along with this program. If not, see <https://owncloud.com/licenses/owncloud-commercial/>.
 *
 */

namespace OCA\Admin_Audit\Handlers;

class CustomGroups extends Base {
	public static function leaveFromGroup($event) {
		self::logLeaveFromGroup('{actor} user {userId} leaves group {groupName}', $event);
	}

	public static function changeRoleInGroup($event) {
		self::logChangeRoleInGroup('{actor} user {user} changed role to {roleDisaplayName}, numeric value {roleNumber}, in group {groupName}', $event);
	}

	public static function updateGroupName($event) {
		self::logCustomGroupNameUpdate('{actor} group name {oldGroupName} is updated to {newGroupName}', $event);
	}

	public static function removeUserFromGroup($event) {
		self::logCustomGroupUserDelete('{actor}: {user} deleted from group {group}', $event);
	}

	protected static function logCustomGroupUserDelete($message, $arguments) {
		self::getLogger()->log($message, [
			'user' => $arguments['user_displayName'],
			'group' => $arguments['group_displayName'],
		]);
	}

	public static function addGroupAndUser($event) {
		self::logCustomGroupCreated('{actor}: group {group} is newly created. User {user} is added to this group as admin', $event);
	}

	protected static function logLeaveFromGroup($message, $arguments) {
		self::getLogger()->log($message, [
			'userId' => $arguments['userId'],
			'groupName' => $arguments['groupName']
		]);
	}

	protected static function logChangeRoleInGroup($message, $arguments) {
		self::getLogger()->log($message, [
			'user' => $arguments['user'],
			'groupName' => $arguments['groupName'],
			'roleDisaplayName' => $arguments['roleDisaplayName'],
			'roleNumber' => $arguments['roleNumber']
		]);
	}

	protected static function logCustomGroupNameUpdate($message, $arguments) {
		self::getLogger()->log($message, [
			'oldGroupName' => $arguments['oldGroupName'],
			'newGroupName' => $arguments['newGroupName']
		]);
	}

	protected static function logCustomGroupCreated($message, $arguments) {
		self::getLogger()->log($message, [
			'group' => $arguments['groupName'],
			'user'  => $arguments['user']
		]);
	}

	public static function deleteGroup($event) {
		self::logCustomGroupDeleted('{actor}: group {group} is deleted', $event);
	}

	protected static function logCustomGroupDeleted($message, $arguments) {
		self::getLogger()->log($message, [
			'group' => $arguments['groupName']
		]);
	}

	public static function addUserToGroup($event) {
		self::logCustomGroupUserAdd('{actor}: user {user} is added to group {group}', $event);
	}

	protected static function logCustomGroupUserAdd($message, $arguments) {
		self::getLogger()->log($message, [
			'user' => $arguments['user'],
			'group' => $arguments['groupName']
		]);
	}
}
